;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xd3a09796c14ff6db57666079b11c0e46 . "./code.cg2js/cg-cursor-pixmap.fasl")
(#xd649822832fe1be47b99a525fb381834 . "./code.cg2js/cg-printing.fasl")
(#xfcb6ff37450828b3accf520d493f8cd6 . "./code.cg2js/cg-caret.fasl")
(#xa01cde1ff7bf688c924d46b48209ba3d . "./code.cg2js/cg-item-list.fasl")
(#xd6e5586efa74165c2fa5073b3b7dd82f . "./code.cg2js/cg-progress-indicator.fasl")
(#xb4e8f370912ba7281966042b2153e75b . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#x717a28a97ba4d6482a687f685b46e95a . "./code.cg2js/cg-outline.fasl")
(#x9cbdeaacd47a69677fa9ee11b42cfe01 . "./code.cg2js/cg-palette.fasl")
(#xd06e2bb24d76c6e1672e168441bbb744 . "./code.cg2js/cg-selected-object.fasl")
(#x82027a138626630b564403114c9657a5 . "./code.cg2js/cg-status-bar.fasl")
(#x4b8ece35a30fefd97e5768d32e23a6fa . "./code.cg2js/cg-wrap-string.fasl")
(#x882594dd99737373b5187e9f96001eb9 . "./code.cg2js/cg-fill-texture.fasl")
(#x24313ef009cfbf10a23cca14aa96b288 . "./code.cg2js/cg-layout.fasl")
(#x62d789994bd06f5f9306dd3631d2b8cc . "./code.cg2js/cg-timer.fasl")
(#x24d677cc8c84cc43787cb7c38d7432ea . "./code.cg2js/cg-dialog-item.fasl")
(#x093b8a3e4e0554ad3a82d6bb3da685cb . "./code.cg2js/cg-button.fasl")
(#x568f2c47bedf97317d46e42c0c6c830e . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#xeac482e1cb7fd842236dfd15d9020bf4 . "./code.cg2js/cg-tray.fasl")
(#x8586c15b9e5b2c0e7514ae3c13d97356 . "./code.cg2js/cg-plot-widget.fasl")
(#xf2b00f2a00011aee6aa15c6263fa76c2 . "./code.cg2js/cg-pixmap.fasl")
(#xe221633dab13140726909104086f901c . "./code.cg2js/cg-font-dialog.fasl")
(#x768ed5d40c3644b60c1f98b95385c8dc . "./code.cg2js/cg-os-widget.fasl")
(#xa234c7cc73f7253ff24b177d6e1ce583 . "./code.cg2js/cg-text-or-combo.fasl")
(#xaa33dcadd4a68eb37d816b8a74009412 . "./code.cg2js/cg-trackbar.fasl")
(#x598bfbede7df931e09706ee1e7de9aab . "./code.cg2js/cg-up-down-control.fasl")
(#xcb87325071d52f02591145aad676fc8b . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xde25a1023bad934f197367a7dc652166 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#x2d9caa134a763c90b4d5f9234c04d228 . "./code.cg2js/cg-intersect-posbox.fasl")
(#x4247e29a8093ac19496ec9e97eca124e . "./code.cg2js/cg-bitmap-stream.fasl")
(#xb9e5c35880639ccef02af18bd406123b . "./code.cg2js/cg-chart-widget.fasl")
(#x08af48d8fb09197aa082e0b61b3e37a4 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x9cecf015958d82c4d96ea70558d6bd70 . "./code.cg2js/cg-group-box.fasl")
(#x010543501f3b4ab839857aabcbd99624 . "./code.cg2js/cg-static-text.fasl")
(#x2d31bdba2b31e9b151ebb039d8e3120e . "./code.cg2js/cg-class-slot-grid.fasl")
(#xa0959ef43fe209d4925ff8887d549ec2 . "./code.cg2js/cg-color-dialog.fasl")
(#x34b038f326acb718dafea09d72314914 . "./code.cg2js/cg-intersect.fasl")
(#x3b09d172ff3f93e73313cf57633c273a . "./code.cg2js/cg-gesture-emulation.fasl")
(#x94d19fac8d021c112105e68b92550142 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x58cf0a3b08d312dc5632d4ba29ffef26 . "./code.cg2js/cg-html-dialog.fasl")
(#x832ddd4f8a49243ee3d3b2d7550243ec . "./code.cg2js/cg-lettered-menu.fasl")
(#x5409ea563dd019d6b2ea204160eeb682 . "./code.cg2js/cg-class-grid.fasl")
(#xe8699e9684b5386c50d6c8d8437f89c6 . "./code.cg2js/cg-pixmap-printing.fasl")
(#xcf4347e3fedb89adb332b47682c3da46 . "./code.cg2js/cg-calendar.fasl")
(#xa6494fb001620de50df9425bcf5e292a . "./code.cg2js/cg-editable-text.fasl")
(#xa038fd2957bdbf2dfc7ca96f1b40a978 . "./code.cg2js/cg-property.fasl")
(#x77f699b646a65a1485085d7d52836ba2 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#x2ebfa6f6b3f1593c30c0fe7550f5e3fe . "./code.cg2js/cg-grid-widget.fasl")
(#x49c4cf72c424809b9cee5c4bb73f8bdc . "./code.cg2js/cg-paren-matching.fasl")
(#x5845301dbca0e8894672ba55303d9415 . "./code.cg2js/cg-dev.fasl")
(#xf798caf5d5c466a74346b68dbe8b667e . "./code.cg2js/cg-drawable.fasl")
(#xfcda69bc60316e9eef39e6e19c99eb25 . "./code.cg2js/cg-curve.fasl")
(#x3c7027649e85bd740926323ac84afc1d . "./code.cg2js/cg-lisp-widget.fasl")
(#xc8af2e27d4081cdc9a6a400fb485cc8e . "./code.cg2js/cg-dde-utils.fasl")
(#x540c602946271fb952aacfb474d75dbd . "./code.cg2js/cg-pixmap-file-io.fasl")
(#xd014f8631ace930d1c3815992f3236e6 . "./code.cg2js/cg-object-editor-layout.fasl")
(#xb86c78ab245f9b7efe85511ea6504d22 . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xc77cf485c7f8d136ea5e47062fc2b65b . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x5f4a10d08e8f72fdebf66ac239ad982d . "./code.cg2js/cg-lamp.fasl")
(#x8b3c83ab90650abc3596af57de9451e6 . "./code.cg2js/cg-common-control.fasl")
(#x2646c6c10ac9c4efebf17a85b26aacad . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xb8c2fa80b2f4164ffcbec1ac452723c9 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x8afc0121e8af11e452db48261658b263 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xc7fa4e50365129daa6a35fd23ac45974 . "./code.cg2js/cg-project-window.fasl")
(#xbaa355a0026e74c89e9575e17fe84e4a . "./code.cg2js/cg-sample-file-menu.fasl")
(#x367aee2a2647879c8e91f525fc02eaf6 . "./code.cg2js/cg-class-support.fasl")
(#x3e190e633008b96935067c26c0da7fd1 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x4dd0f8bb93b544744c87ba63a54ea3a0 . "./code.cg2js/cg-yes-no-list.fasl")
(#xed18e91324e1867f23e81be57d8853dc . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x54944cf2c058cfabe72ce5f13ac8b111 . "./code.cg2js/cg-string-dialog.fasl")
(#x4fcffe9dd3c3f1788fc554a58091692a . "./code.cg2js/cg-menu-tooltip.fasl")
(#x8981da3eeb40cd4866918ab0374a8297 . "./code.cg2js/cg-dropping-outline.fasl")
(#xcc242b46ff157466aa3b41b3baea39ab . "./code.cg2js/cg.fasl")
(#x21f51c7974c52fa1c80fcef6c5b4bf75 . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x7799d07cfae0a163cd1774fb563089b3 . "./code.cg2js/cg-scaling-stream.fasl")
(#x47ad6a5d168aa7cc7adbf169c77e2b15 . "./code.cg2js/cg-yes-no-string.fasl")
(#x58caa4a1c65f3631bb0160d956cd46e5 . "./code.cg2js/cg-icon-pixmap.fasl")
(#xa67ce9b5dbfd8e6e5f20e672711ad9af . "./code.cg2js/cg-web-browser.fasl")
(#xe58e0ff534b0063f09add0da8f595175 . "./code.cg2js/cg-clipboard-stack.fasl")
(#xe41d6b7a84b6f0a8ffddac428cc43ca8 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x9ae3716f58c6804fd33f9a69024ab262 . "./code.cg2js/cg-message-dialog.fasl")
(#x724291b2492a1130b831d790070088a2 . "./code.cg2js/cg-comtab.fasl")
(#x8b4cfffe7d9c86672bcaaf759d8e3d8c . "./code.cg2js/cg-base.fasl")
(#xe4b69ab933f45fa3afd7b6e35f2eb1d3 . "./code.cg2js/cg-pixmap-widget.fasl")
(#xf2bc28bfa515eda5cc6eecd263685ebc . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x0903cccb004dbb3061f519831418d8bd . "./code.cg2js/cg-text-edit-pane.fasl")
(#x7b0f660c07c5467382b75027fb8f921b . "./code.cg2js/cg-utility-dialog.fasl")
(#x0aab70b125abb32763b3e4ee23aaf291 . "./code.cg2js/cg-object-editor.fasl")
(#xf3841d417cafed7f668ffabecab47cf9 . "./code.cg2js/cg-edit-in-place.fasl")
(#x83094a86a880f55df62c786b216042ef . "./code.cg2js/cg-radio-button.fasl")
(#xb1d567879c10009b70a4823c3e51af43 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#x34a150799e31af17b0a29c0384878669 . "./code.cg2js/cg-nodes.fasl")
(#x0b5815bf4badbb3f3548f82bf469408e . "./code.cg2js/cg-get-position.fasl")
(#x30b7e1f9d824bb1b932a41afe78a7662 . "./code.cg2js/cg-directory-dialog.fasl")
(#xf51ba45fe7314d3f22c287d8599075bd . "./code.cg2js/cg-lisp-text.fasl")
(#xba39c0f8aa9968207b0f2f4d546f19ec . "./code.cg2js/cg-combo-box.fasl")
(#xc1be7f990c8ad55bfdf8e042b6917c58 . "./code.cg2js/cg-text-widget.fasl")
(#x87b1176c28fb30bd05164ac56ee498ba . "./code.cg2js/cg-list-view.fasl")
(#x5fbe6eea3be10dc7bdd43d4019fc393a . "./code.cg2js/cg-header-control.fasl")
(#xe5da77113d056d8907e072e9738860ba . "./code.cg2js/cg-graphics-context.fasl")
(#x1308c51987286d22b2a1418ac9700df6 . "./code.cg2js/cg-get-pixmap.fasl")
(#x6b812d10e2ff20704575aa47654b6495 . "./code.cg2js/cg-menu.fasl")
(#x42f0cd089f7dd490170e58f378172687 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#x47c90fcd9ceabb119aaf66a020687596 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x283489eb498649f76f97be3b354ee73c . "./code.cg2js/cg-tooltip.fasl")
(#x0cfb81c93c61d9ba481e0e3f3b4797f5 . "./code.cg2js/cg-html-widget.fasl")
(#xcc9f9b055701bda47a66019896efa60e . "./code.cg2js/cg-choice-list.fasl")
(#x4a715cfc9d50e24fdf86efffaf527d57 . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xf6694b92bd49fa8ec8f761d3097e8fef . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x8f8a8cf2ceee119c72fe0ca946b694a8 . "./code.cg2js/cg-icon.fasl")
(#xbfc92e1743c3d2642a9ee9291117aeba . "./code.cg2js/cg-acache.fasl")
(#x56d9829ed100ff2ccaf525dc6df795ca . "./code.cg2js/cg-template-string.fasl")
(#x26587bc1193a2838536df9ba2e1328b9 . "./code.cg2js/cg-bitmap-pane.fasl")
(#xb09994cc55426b5ea6895ae914f60c3a . "./code.cg2js/cg-toggling-widget.fasl")
(#x2191e40e1a77e34d729567f6c67e1f06 . "./code.cg2js/cg-tab-control.fasl")
(#x4f28bf960f590caed4944b5279609609 . "./code.cg2js/cg-split-bar.fasl")
(#x4a7f53012a9c1ab0889ee2f174aebc98 . "./code.cg2js/cg-picture-widget.fasl")
(#x36dc53443bbc64ab34c2bd094b2541c5 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x09933ce6468511bcb4db01aaef0e7c75 . "./code.cg2js/cg-choose-printer.fasl")
(#xba031e43506c36fa39209084b67ef1e8 . "./code.cg2js/cg-os-window.fasl")
(#x7f11392ae7f349c508e4ea6dabf6ace3 . "./code.cg2js/cg-scroll-bar.fasl")
(#xa83d6092bc9a471ee505655b1b5b5556 . "./code.cg2js/cg-clipboard.fasl")
(#x890445508d36a4b0ef7a9ca8cdff51b9 . "./code.cg2js/cg-find-string-dialog.fasl")
(#x3ce593fdbce8979fdc2fcc837ace9d30 . "./code.cg2js/cg-hotspot.fasl")
(#x257a6ef4d89d57e04f599bba11c03ff4 . "./code.cg2js/cg-rich-edit.fasl")
(#xfd11fd78b1a84785ab3fb9817c6ce9a1 . "./code.cg2js/cg-check-box.fasl")
(#xd559759f74b02134a3088157f5923305 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x20f42f205f5440ebc5f276bfe50dd39e . "./code.cg2js/cg-file-dialog.fasl")
(#xcb894f44e5d3eb8dec81c530f42b534a . "./code.cg2js/cg-toolbar.fasl")
(#x064470d34dac913bc53838a188aad77f . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#xb74bcd51e80b33edf20e67b645e565ce . "./code.cg2js/cg-chart-or-plot.fasl")
(#x8df22dbcf2681a11e60e75ee536caac5 . "./code.cg2js/cg-shortcut-menu.fasl")
(#x2dedcbbb0cf5fb1da6966a8df9798f66 . "./code.idejs/ide-project.fasl")
(#x29d8f5dd4c8c75bef82a23c604ec1dbb . "./code.idejs/ide-intro.fasl")
(#xa0326b295c96042df6fa7253dd5c10fa . "./code.idejs/ide-find-in-files.fasl")
(#x686ee26b5560e3429d57d9e36b1ecb2d . "./code.idejs/ide-grapher.fasl")
(#x5278ae2988e038d342c38f25c2958027 . "./code.idejs/ide-inspector.fasl")
(#xb87c6a089c7cfe16cf3f58645f29a9d3 . "./code.idejs/ide-editor.fasl")
(#xc13566f7d02529bad00563afc8e812f3 . "./code.idejs/ide-window-list.fasl")
(#x236d7d7d47e41eac8bc22e8fdb1afe9c . "./code.idejs/ide-process-browser.fasl")
(#xe7dc507e7ab8fec9a866aac726bbb8aa . "./code.idejs/ide-patch-dialog.fasl")
(#x40a4eb7338dae07fee4b80b980aacdbc . "./code.idejs/ide-class-grapher.fasl")
(#x188bb5a39a8da93139a329e289974cc5 . "./code.idejs/ide-base.fasl")
(#xd478c2f95e090f76a98ea76581ad5b5b . "./code.idejs/ide.fasl")
(#x12a87045d82d6db4d3d7c43cd5b28e01 . "./code.idejs/ide-trace.fasl")
(#xf7e192ea76c934e5694dc4c213d72e2b . "./code.idejs/ide-form.fasl")
(#x8c70ceaf1a123b0fa99ad7f4628bb21c . "./code.idejs/ide-find-definitions.fasl")
(#xd8d141b63548c7f108b930dffe622606 . "./code.idejs/ide-apropos.fasl")
(#x72e16524df9fdc7aaa665f64a00e2eea . "./code.idejs/ide-class-browser.fasl")
(#xf616457f9b85494a6fb6aae8138b5675 . "./code.idejs/ide-navigator.fasl")
(#x80ad1e20ba17dfd1407e58e9e38ea9ea . "./code.idejs/ide-clipboard.fasl")
(#x08a1e37f81f258d13d5eb2b80211cdd7 . "./code.idejs/ide-acache.fasl")
(#x336a71d5412c041551a05eae402b97c5 . "./code.idejs/ide-keyshort.fasl")
(#x9b4c0ea77b2f3f7b6be68c1f9635ee92 . "./code.idejs/ide-package-list.fasl")
(#x66b868752ae1d059db31fd70eb9bc599 . "./code.idejs/ide-dev.fasl")
(#x785b009207cd19fe54c93fc535e484ec . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
